package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````@"````````!``````````#BQ````
M`````````$``.``)`$``'``;``8````%````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````.B=````````Z)T`````````
M`"````````$````&````8*L```````!@JR```````&"K(```````P`0`````
M``!(%0``````````(````````@````8```"(JP```````(BK(```````B*L@
M``````!``@```````$`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M`````)<`````````EP````````"7````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````&"K````````8*L@``````!@JR``
M`````*`$````````H`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50"BTO9W>OGFFS6,X_BSMT8EGN$W.Q$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````_`$``!(`````````````````````````<@(``!(`
M````````````````````````4`(``!(`````````````````````````$0``
M`"``````````````````````````>0(``!(`````````````````````````
M!0,``!(`````````````````````````M````!(`````````````````````
M````C@(``!(`````````````````````````@P$``!(`````````````````
M````````[0(``!(`````````````````````````Y0(``!(`````````````
M````````````A````!(`````````````````````````U`,``!(`````````
M````````````````#`$``!(`````````````````````````L0(``!(`````
M````````````````````HP(``!(`````````````````````````80(``!(`
M````````````````````````_@(``!(`````````````````````````&P,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````*0(``!(`````````````````
M````````6`(``!(`````````````````````````.0(``!(`````````````
M````````````G@$``!(`````````````````````````AP(``!(`````````
M````````````````]P$``!(`````````````````````````7P,``!(`````
M````````````````````6`,``!(`````````````````````````0P$``!(`
M````````````````````````#@,``!(`````````````````````````+0``
M`"``````````````````````````Q0(``!(`````````````````````````
M9````!(`````````````````````````%0(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````S`(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````?P(``!(`````````````````````````\`$`
M`!(`````````````````````````20,``!(`````````````````````````
M(@,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````40,``!(`````````````````
M````````G`(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````V@(``!(`````````
M````````````````2P(``!(`````````````````````````#0(``!(`````
M````````````````````MP(``!(`````````````````````````/````"``
M````````````````````````E0(``!(`````````````````````````+`,`
M`"(`````````````````````````J@(``!(`````````````````````````
M.P,``!(`````````````````````````W0,``!(`#@"@5@```````'``````
M````JP,``!(`#P"D5P```````````````````@0``!(`#@!01@```````%0,
M````````;`,``!(`#@!0'@```````"T"````````L0,``!(`#@"0/P``````
M``4`````````<`0``!(`#@"@/P```````!H"````````:@0``!(`"P!@&@``
M````````````````G00``!(`#@"P4@```````.T#````````D`,``!``&0`@
ML"``````````````````Z0,``!(`#@#`00```````"H`````````'`0``!$`
M$`"P5P````````0`````````O`$``!$`%0!PJR```````!,`````````G`,`
M`!``&0"HP"``````````````````:`0``!(`#@!`/@```````#``````````
M?00``!(`#@!P10```````-P`````````CP0``!(`#@#`1````````'0`````
M````#P0``!``&```L"``````````````````]@,``!(`#@#P00```````.P`
M````````<0,``!$`&0!(L"````````@`````````B0,``!``&``@L"``````
M````````````<@,``"$`&0!(L"````````@`````````400``!$`&``8L"``
M``````@`````````]P(``!$`&0!@L"````````@`````````H0,``!(`#@"@
M5P````````(`````````000``!(`#@`P5P```````&4`````````%00``!(`
M#@"`(````````"L`````````$00``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````<P,``"$`&0!(L"````````@`````````
MP@,``!(`#@!`10```````"0`````````*P0``!(`#@#`/@```````,$`````
M````XP```!$`&0!`L"````````$`````````6P0``!(`#@#@0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E
M861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`
M86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U
M7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R
M7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?
M:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?
M,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C0````"``,``@`"`````@`"`````@````(``@````(````"``(`!``"
M``(````````````#``(`!0````(``P`"``(````&````!P````,``@``````
M```````````&```````"``,``@`"```````"``(```````(``@`#``8````"
M``(``@`&``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0`!``(`
M`0`"``$``@`!``$``0`!`````@`!``$````!`````0`!`.`!```0````(```
M`'4::0D```,`LP0````````!``4`+P(``!``````````E)&6!@``!P"_!```
M$````'09:0D```8`R@0``!````!R&6D)```%`-8$```0````%&EI#0``!`#B
M!```$````'4::0D```(`LP0```````!@JR````````@`````````@"$`````
M``!HJR````````@`````````0"$````````(L"````````@`````````"+`@
M```````8L"````````@`````````R%H```````"XKR````````8````%````
M``````````#`KR````````8````*``````````````#(KR````````8````?
M``````````````#0KR````````8````C``````````````#8KR````````8`
M```K``````````````#@KR````````8````V``````````````#HKR``````
M``8````_``````````````#PKR````````8```!!``````````````!PJR``
M``````4```!/```````````````@L"````````4```!?``````````````!`
ML"````````4```!C``````````````!(L"````````4```!6````````````
M``!@L"````````4```!:``````````````#@K2````````<````!````````
M``````#HK2````````<````"``````````````#PK2````````<````#````
M``````````#XK2````````<````$````````````````KB````````<````&
M```````````````(KB````````<````'```````````````0KB````````<`
M```(```````````````8KB````````<````)```````````````@KB``````
M``<````+```````````````HKB````````<````,```````````````PKB``
M``````<````-```````````````XKB````````<````.``````````````!`
MKB````````<````/``````````````!(KB````````<````0````````````
M``!0KB````````<````1``````````````!8KB````````<````2````````
M``````!@KB````````<````3``````````````!HKB````````<````4````
M``````````!PKB````````<````5``````````````!XKB````````<````6
M``````````````"`KB````````<````7``````````````"(KB````````<`
M```8``````````````"0KB````````<````9``````````````"8KB``````
M``<````:``````````````"@KB````````<````;``````````````"HKB``
M``````<````<``````````````"PKB````````<````=``````````````"X
MKB````````<````>``````````````#`KB````````<````@````````````
M``#(KB````````<````A``````````````#0KB````````<````B````````
M``````#8KB````````<````D``````````````#@KB````````<````E````
M``````````#HKB````````<````F``````````````#PKB````````<````G
M``````````````#XKB````````<````H````````````````KR````````<`
M```I```````````````(KR````````<````J```````````````0KR``````
M``<````L```````````````8KR````````<````M```````````````@KR``
M``````<````N```````````````HKR````````<````O```````````````P
MKR````````<````P```````````````XKR````````<````Q````````````
M``!`KR````````<````R``````````````!(KR````````<````S````````
M``````!0KR````````<````T``````````````!8KR````````<````U````
M``````````!@KR````````<````W``````````````!HKR````````<````X
M``````````````!PKR````````<````Y``````````````!XKR````````<`
M```Z``````````````"`KR````````<````[``````````````"(KR``````
M``<````\``````````````"0KR````````<````]``````````````"8KR``
M``````<````^``````````````"@KR````````<```!```````````````"H
MKR````````<```!"``````````````"PKR````````<```!#````````````
M``!(@^P(2(L%994@`$B%P'0"_]!(@\0(PP```````````/\U2I,@`/\E3),@
M``\?0`#_)4J3(`!H`````.G@_____R5"DR``:`$```#IT/____\E.I,@`&@"
M````Z<#_____)3*3(`!H`P```.FP_____R4JDR``:`0```#IH/____\E(I,@
M`&@%````Z9#_____)1J3(`!H!@```.F`_____R42DR``:`<```#I</____\E
M"I,@`&@(````Z6#_____)0*3(`!H"0```.E0_____R7ZDB``:`H```#I0/__
M__\E\I(@`&@+````Z3#_____)>J2(`!H#````.D@_____R7BDB``:`T```#I
M$/____\EVI(@`&@.````Z0#_____)=*2(`!H#P```.GP_O___R7*DB``:!``
M``#IX/[___\EPI(@`&@1````Z=#^____);J2(`!H$@```.G`_O___R6RDB``
M:!,```#IL/[___\EJI(@`&@4````Z:#^____):*2(`!H%0```.F0_O___R6:
MDB``:!8```#I@/[___\EDI(@`&@7````Z7#^____)8J2(`!H&````.E@_O__
M_R6"DB``:!D```#I4/[___\E>I(@`&@:````Z4#^____)7*2(`!H&P```.DP
M_O___R5JDB``:!P```#I(/[___\E8I(@`&@=````Z1#^____)5J2(`!H'@``
M`.D`_O___R52DB``:!\```#I\/W___\E2I(@`&@@````Z>#]____)4*2(`!H
M(0```.G0_?___R4ZDB``:"(```#IP/W___\E,I(@`&@C````Z;#]____)2J2
M(`!H)````.F@_?___R4BDB``:"4```#ID/W___\E&I(@`&@F````Z8#]____
M)1*2(`!H)P```.EP_?___R4*DB``:"@```#I8/W___\E`I(@`&@I````Z5#]
M____)?J1(`!H*@```.E`_?___R7RD2``:"L```#I,/W___\EZI$@`&@L````
MZ2#]____)>*1(`!H+0```.D0_?___R7:D2``:"X```#I`/W___\ETI$@`&@O
M````Z?#\____)<J1(`!H,````.G@_/___R7"D2``:#$```#IT/S___\ENI$@
M`&@R````Z<#\____);*1(`!H,P```.FP_/___R6JD2``:#0```#IH/S___\E
MHI$@`&@U````Z9#\____)9J1(`!H-@```.F`_/___R62D2``:#<```#I</S_
M__\EBI$@`&@X````Z6#\____)8*1(`!H.0```.E0_/___R5ZD2``:#H```#I
M0/S___\EJI$@`&:0``````````!54TB#[#B)?"0<2(ET)!!(C7PD'$B)5"0(
M2(UT)!!(C50D"&1(BP0E*````$B)1"0H,<#H"/[__TB+-4F1(`!(BSU*D2``
M2(GRZ'(X``"`/9N1(```=2_H-/W__TB%P$B)!>JA(``/A+<!``!(B<?H;/S_
M_XL]5I$@`.C1_?__QH#1"````(L]1)$@`.B__?__@(BJ!````HL],I$@`.BM
M_?__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'#X<B`0``2,'G`TB-
M'6`Z``#H^?S__TB+?"002(D%5:$@`,<%4Z$@``0```!(BQ=(B5@(2(T=.CH`
M`$B)6!A(B1!(BQ6_D"``2(E0$(M4)!R#^@%$C4H$?BU$C4H$2(/'"+X%````
M9@\?A```````3(L'2&/.@\8!2(/'"$$Y\4R)1,CX=>E(BST"H2``36/)2(TU
MR!X``(/"`T4QP$K'1,CX`````$B)P>AA_?__A<")PW1D2(L]U*`@`$B-;"0D
MZ-K[__](C3UW.```,<!(B>[HN1<``$B%P'0J2(L]K:`@`.A8^___Z//\__^)
MV$B+7"0H9$@S'"4H````=5](@\0X6UW#2(L]>Z`@`$B%_W0LZ'DV``#KPTB+
M/7"@(`#HB_W__XG#ZXQ(C34PBR``2(T]OS<``#'`Z(+\__](C3VT-P``2(GN
MZ$,7``!(A<!(B<=(B04NH"``=(#KM.@-^___OP$```#H8_W__P\?`#'M28G1
M7DB)XDB#Y/!05$R-!0HW``!(C0V3-@``2(T]K/W___\5'H\@`/0/'T0``$B-
M/6F/(`!52(T%88\@`$@Y^$B)Y7092(L%ZHX@`$B%P'0-7?_@9BX/'X0`````
M`%W##Q]``&8N#Q^$``````!(C3TICR``2(TU(H\@`%5(*?Y(B>5(P?X#2(GP
M2,'H/T@!QDC1_G082(L%R8X@`$B%P'0,7?_@9@\?A```````7<,/'T``9BX/
M'X0``````(`](8\@``!U+TB#/9^.(```54B)Y70,2(L]JHX@`.C=_/__Z$C_
M___&!?F.(``!7<,/'X``````\\-F#Q]$``!52(GE7>EF____9@\?1```05=!
M5DR-3SA!54%413'`55-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)X6:0
M0XL$`4N+-`$/R$B)\HG`2,'J($J)!$%(B?!(P>XX2,'H*"4`_P``2`GP2(G6
M2,'B"$C!YAB!X@``_P")]D@)\$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"```/
M'X``````2(M!:$@S04!(@\$(2#-!"$@S0?A(C10`2,'H'T@)T(/@_TB)07A(
M.?%UU4R+%TB+7Q!(BW<@2(MO&$R+3PA,B=!,B=)(P>H;2,'@!4@)T`,$)(V4
M,)EY@EI(B=A(BW0D"$@QZ$PAR$@QZ$B-M#69>8):1(TL`DR)RDR)R$C!Z`)(
MP>(>2`G"2(G838GHB=%)P>@;2#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,
MB=9,B=!(P>8>2,'H`D@)\$B+="0038GC2#'"2<'K&T&)P$PAZDB-M#.9>8):
M2#'*2`'R3(GF2,'F!4P)WD2-'!9,B>Y(BU0D&$G![0)(P>8>3`GN2#'P2(V4
M$9EY@EI,B=E,(>!!B?9,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)$C2P"
M2,'A'DB+5"0@3`GA2(GP2#'(3(GN08G,3"'828V4$)EY@EI(P>X;3#'P2`'0
M3(GJ2,'B!4@)\D2-!`),B=I(BT0D*$G!ZP)(P>(>3`G:3(G&2#'128V$!IEY
M@EI(P>X;3"'I08G33#'A2`'!3(G`2,'@!4@)\$2--`A,B>A(BTPD,$G![0)(
MP>`>3`GH3(GV2#'"28V,#)EY@EI!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)
M\4R)QDG!Z`)$C2012,'F'DB+5"0X3`G&2#'P3(GA08GP3"'P28V4$YEY@EI(
MP>D;3#'H2`'03(GB2,'B!4@)RDR)\4G![@)$C1P"2,'A'DB+5"1`3`GQ2(GP
M2#'(3(G>08G.3"'@28V4%9EY@EI(P>X;3#'`2`'03(G:2,'B!4@)\D2-+`),
MB>)(BT0D2$G![`)(P>(>3`GB3(GN2#'128V$`)EY@EI(P>X;3"'908G43#'Q
M2`'!3(GH2,'@!4@)\$2-!`A,B=A(BTPD4$G!ZP)(P>`>3`G83(G&2#'"28V,
M#IEY@EI(P>X;3"'J08G#3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)$C3012,'F
M'DB+5"183`GN2#'P3(GQ08GU3"'`28V4%)EY@EI(P>D;3#'82`'03(GR2,'B
M!4@)RDR)P4G!Z`)$C20"2,'A'DB+5"1@3`G!2(GP2#'(3(GF08G(28V4$YEY
M@EI,(?!(P>X;3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"
M3`GR3(G>2#'128V$!9EY@EI(P>X;3"'A08G63#'!2`'!3(G82,'@!4@)\$2-
M+`A,B>!(BTPD<$G![`)(P>`>3`G@3(GN2#'"28V,")EY@EI(P>X;3"':08G$
M3#'R2`'*3(GI2,'A!4@)\4R)WDG!ZP)$C0012,'F'DB+5"1X3`G>2#'P3(G!
M08GS3"'H28V4%IEY@EI(P>D;3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)$C30"
M2,'A'DB+E"2`````3`GI2(GP2#'(3(GV08G-3"'`28V4%)EY@EI(P>X;3#'8
M2`'03(GR2,'B!4@)\D2-)`),B<)(BX0DB````$G!Z`)(P>(>3`G"3(GF2#'1
M28V$`YEY@EI(P>X;3"'Q08G03#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<
M"$R)\$G![@)(P>`>3`GP28VT-9EY@EI-B=U(,<))P>T;B<%,(>),,<)(`?),
MB=Y(P>8%3`GNB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'8
M3XV$()EY@EI(,<A-B>Q)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))
MP>`>08G$30G828GSB?9-,<-(`[0DJ````$0QVDR+G"2@````2HV,&:'KV6Y-
MB>-)P>L;2`'13(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%
MB<!),=5,`X0DL````$0QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!
M\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BA
MZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9)
M,<M(`[0DP````$0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)
MZ$G![0)(P>`>08G33`GH28G-B<E),<5(`XPDR````$4QZ$V)W4Z-A`:AZ]EN
M3(G>2<'M&TC!Y@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$
M,>)-B>Q(C8P1H>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!
MZP)(P>(>08G,3`G:38G#18G`23'33`.$)-@```!$,=Y-B>-(C;0PH>O9;DR)
MX$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G223'U2`.4
M).````!$,>E-B=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"
M2,'A'D6)Q4P)X4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)
MX(G`2`'"3(G82`.T).@```!)P>L"2,'@'D&)U$P)V$F)RXG)23'#2`.,)/``
M``!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@
M'D&)\TT)Z$F)Q8G`33'%2`.$)/@```!$,>I-B=U(C8P1H>O9;DR)VDG![1M(
MP>(%3`GJB=)(`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-
MM#"AZ]EN3(GH2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"3`.$)``!``!,
M"=Y)B=-!B<1),?.)TD@#E"0(`0``1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A
M!4P)V8G)20'(3(GI2<'M`DC!X1Y%B<-,">E)B?6)]DDQS4@#M"00`0``1#'H
M38G=2(V4`J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,
M">!)B<R)R4DQQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)
MV$G!ZP))P>`>08GT30G82`.,)!@!``!)B<--,<.)P$@#A"0@`0``1#':38GC
M2<'K&TB-C!&AZ]EN3(GB2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-
MB<5%B<!),=5,`X0D*`$``$0Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)
MP$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)),?1(`Y0D,`$``$0QX4V)[$V-
MA`BAZ]EN3(GI2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GS
MB?9),<M$,=A-B>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P0
M3(GH2<'M`DC!X!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;
M2,'F!4P)[DR+K"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G0
M2"'P32'<20G$N-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!
MS$R)V4G!ZP)(P>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)
MT4TAQDPAX4P)\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$
MC30.3(GF2<'L`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$
M30'C38GT3`':38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$
MB=I,"=Y)(=5,(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%
M30GH18TL,$V)\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!
M``!)`<9,`?%-B>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)
MX4F)]$&)RTD)R$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L
M&TC!X@5,">)&C20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,
MBZPD>`$``$D!Q4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(
MP>8>3`GV38G&B?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)
MZTG!XP5)P>X;30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N
M3`GF3(ND)(@!``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)
MP>T"2<'@'DT)Z$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE
M20'+3(GA2<'M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-
M(=Y-(>!-"?!,B[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT
M`DR)XDG![`)(P>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,
M`>9-B?1(`?%,B?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ
M2`GR22'-3"'R3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)
MZT6-+!--B?-)P>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``
M20'&30'P38GN3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)
MB=1$B<9-"<-)(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(
MP>$%3`GA1HTD&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL
M),`!``!)`<5,`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B
M'DV)V$P)\D&)UD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN
M2<'H&TC!Y@5,"<9$C00.3(GF2<'L`DC!YAY,B?%,">9!B?1("?),(>%,(>I(
M"<I(BXPDT`$``$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4G!ZQM,"=F)
MR4P!\$@!RDR)Z4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=
M2`'P3(G>2<'M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,
M,<$QRDB+C"3@`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)
MV4C!X1Y)P>L"08G420G+3(G!38GF3#'92<'N&T6)P#'(2(N,).@!``!(`?%)
M`<]*C0PX3(G@2,'@!4P)\(G`3(TT`4R)Z$G![0)(P>`>3(G918G;20G%2(N$
M)/`!``!%B?=,,>DQRDR)^4@!\$C!Z1M,`<!(`<),B?A(P>`%2`G(2(N,)/@!
M``")P$@!PDR)X$G![`)(P>`>2`'Q08G03`G@3`'938GK23'#38G$18GM13'>
M2<'L&TZ-'#%,B<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0`
M`@``2`'Q3`'I28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)
MP>@"B=)(P>$>20'52(N4)`@"``!,"<%-B?A%B>Y%B?]),<A(`?)%,<-(`=!,
MB?).C0083(GP2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)
M"<1(BX0D$`(``$PQXD$QU4R)VD@!\$P!^$D!Q4R)V$C!X`5(P>H;2`G03(GR
M2<'N`HG`2,'B'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(
M3(GY20'`3(GX2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$
M)"`"``!,B?%(P>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+
MC"0H`@``B<!)`<1,B?A)P>\"2`'Q2,'@'D6)Y4P)^$@!RDR)V4@QP46)VT$Q
MR$R)Z4D!T$R)ZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+
ME"0P`@``3(GY2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,
MB>E)P>T"B=)(P>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!
M,=!,B>))`<!,B>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)
MQ4D)QTB+A"1``@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,
MB>))P>P"B<!(P>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](
M,=&)TD$QR$J-#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!
MB<A)"<5(BX0D4`(``$TQ[$4QXTV)Q$@!\$G![!M,`?A)`<-,B<!(P>`%3`G@
MB<!)`<-,B?!(P>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'"
M,=%)C10.3(GA38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(
M2(N,)&`"``!(`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GI
MB<E)`<M,B>%)P>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A
M,<I(C0P03(GH3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"
M``!(`<&)R$@!\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#
M2,'H`DG!XQY!`=!,B>I)"<-(BX0D>`(``$C!XAY)P>T"00';20G51(GB3(E?
M$$@!\$0![4@!PDR)\$B);QA,,>@QP4B-!`I,B<),B<%(P>(%2,'I&T4!R$@)
MRDR)1P@!T$$!PD0#=R!(BX0DB`(``&1(,P0E*````$R)%TR)=R!U$DB!Q)@"
M``!;74%<05U!7D%?P^CBX___9I!!5T%6055!5%532(/L"$B%_P^$L0```$R+
M/8IX(`!-A?\/A*$````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D
M3(G]#Q^``````$R)XDR)]DB)W^C"XO__A<!U!T*`/",]=$=(@\4(2(M=`$B%
MVW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$
M/#UU[T$I_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/
M'T``55-(B?U(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^@#
M____2(7`=#9(8U0D!$B+!9IW(`!(C0302(M0"$B%TDB)$'329I!(@\`(2(M0
M"$B%TDB)$'7PZ[YF#Q]$``!(BT0D"&1(,P0E*````'4'2(/$&%M=P^B,XO__
M9I!F+@\?A```````05=!5D%505154TB)\TB)_4B#["AD2(L$)2@```!(B40D
M&#'`,<"`/CT/E,!(`<-(B=_H.>+__TB-="0428G$2(GO,<#H5_[__TB%P`^$
M#@$``$B)QTF)Q>@3XO__3#G@#X/B````3&-T)!1)P>8##[9%`(3`#X2M`0``
M/#T/A*4!``!(B>CK#0\?A```````@/H]=`M(@\`!#[80A-)U\$@IZ$B83`,U
MG'8@`$J-?"`"Z/KB__](A<!)B08/A'L!``!(8U0D%$B+!7IV(`!(C4T!2(L4
MT`^V10`\/8@"=":$P'40ZR!F+@\?A```````/#UT$DB#P0$/MD'_2(/"`83`
MB`)UZL8"/3'`#Q]$```/M@P#B$P"`4B#P`&$R77P,<!(BW0D&&1(,S0E*```
M``^%$0$``$B#Q"A;74%<05U!7D%?PP\?`$B#PP$/MD/_28/%`83`08A%_W7L
MZ\)FD$R+/>%U(`!)@S\`#X2_````3(GX,=+K"P\?A```````1(GJ2(/`"$2-
M:@%(@S@`=>^-<@-(8_9(P>8#BP7?A2``A<!U6TB)]\<%SH4@``$```#H^>'_
M_TB%P`^$?0```$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+H@N+__TR+1"0(
M2(G!2(D%6W4@`$K'1,$(`````$2);"04Z6_^__],B?_H..+__TB%P$B)P4B)
M!3-U(`!T)DUCQ4Z--,4`````Z\D/'T``,<#I=O[__Y"^$````$4Q[>E>____
MN/_____IV_[__^@TX/__#Q]``$%7059!54%455-(@>RX````9$B+!"4H````
M2(F$)*@````QP$B%_W0(@#\`28G^=2](BX0DJ````&1(,P0E*`````^%)`$`
M`$B!Q+@```!;74%<05U!7D%?PV8/'T0``.AKW___2(7`2(G#=,1(C40D$$B-
M+>P;``!,C27D&P``3(T]X!L``$B)!"1(B=_HC>'__TB%P`^$M````$R-2!.Y
M`@```$B)[TR)SO.F=-RY`P```$R)SDR)Y_.F=,U,B?=,B4PD".A5W___3(M,
M)`A)B<5,B<_H1=___T&-?`4"2&/_Z'C@__],BTPD"$F)Q4B)QTV)\$R)^4C'
MPO____^^`0```#'`Z-3A__](BQ0DOP$```!,B>[HH][__X/X_TR)[W00BT0D
M*"4`\```/0!```!T,.@FWO__3(GOZ/[=___I1/___V8/'X0``````$B)W^A8
MW___3(GWZ+#>___IS/[__^B6_O__Z\[HO][__P\?1```9BX/'X0``````%-(
MB?N+/49S(`#HP=___TB-D``"``!(B=Z_`0```.C=X/__A<!T"3'`6\,/'T0`
M`(L]&G,@`.B5W___BX`8`@``)0#P```]`$```'0=BSW]<B``Z'C?__^+@!@"
M```E`/```#T`H```=;U(B=^^`@```.A)X/__A<`/E,`/ML!;PP\?1```9BX/
M'X0``````$%6055)B?9!5%5)B?Q32(T]2!H``+K_#P``2('L$!```$B)XTB)
MWF1(BP0E*````$B)A"0($```,<#H0=W__X7`#XZ)````C5#_1(LM;W(@`$AC
MZH`\+`!T5DACZ$B)ZKXO````2(G?Z&/>__](A<!T1D2)[^C&WO__2(GI2(G:
M3(GF2(G'Z,7?__](BX0D"!```&1(,P0E*````'4[2('$$!```%M=05Q!74%>
MPV:0A=)UJ0\?0`!$B>_H@-[__TR)\DR)YDB)Q^B2W?__Z[M$BRWI<2``Z]_H
M0MW__V:02(/L"(L]UG$@`.A1WO__2(L5:G$@`$B-#5,;``!(C35H&0``2(G'
M2(/$".EPWO__2(/L"(L]IG$@`.@AWO__2(G'Z+G___^+/9-Q(`#H#M[__TR-
M!<8:``!(C140%```2(TU01D``$4QR4B)QTB#Q`A,B<'I=][__P\?@`````!5
M4TB!["@@``!D2(L$)2@```!(B80D&"```#'`2(GC2(VL)!`0``#H%-S__TR-
M#=48``!(C0T#&0``08G`N@$0``"^`0```$B)WS'`Z!_?__^Z`!```$B)[DB)
MW^B_V___A<!X4XUX`4B)PTAC_^A]W?__2(7`2(G!=!A(8]M(B>Y(B<=(B=KH
M--W__TB)P<8$&`!(BY0D&"```&1(,Q0E*````$B)R'432('$*"```%M=PP\?
M1```,<GKU^C_V___#Q]$``!F+@\?A```````Z2O___^09BX/'X0``````$%7
M059!54%428GT55-(B?M(C3U2&```2('L*!```&1(BP0E*````$B)A"08$```
M,<!(C70D#.C%]___OB\```!(B=](B<7HM=O__TB%P'1`2(T]&Q@``$B)WC'`
MZ/_X__](B=A(BXPD&!```&1(,PPE*`````^%F@$``$B!Q"@0``!;74%<05U!
M7D%?PP\?`$B)W^@XV___2(TUX!<``$R)YT&)Q>A6W?__2(7`28G'=)Y!@\4!
M08`_`$R-9"003(TUNQ<```^$X@````\?0`!(A>UT$TR)_DB)[^C0V___A<`/
MA*(```!,B?_HX-K__XG"2)A!@'P'_R]U%P\?0`"#Z@%(8\)!@'P'_R]!Q@0'
M`'3M1`'J@?K_#P``#X\N____2(/L"$B-#4@8``!-B?%338GXN@`0``"^`0``
M`$R)YS'`Z$C=__^+/3)O(`#HK=O__TB-D``"``!,B>:_`0```.@)VO__A<!:
M674=BST-;R``Z(C;__^+@!@"```E`/```#T`@```=%Y(C37N%@``,?_H:-S_
M_TB%P$F)QP^$K/[__T&`/P`/A2+___](A>UT'4B-/5L6``"Y`@```$B)[O.F
M=,1F+@\?A```````3(T]/A8``+H!````Z3+___\/'X``````O@$```!,B>?H
M^]O__X7`=9%(C3UR%@``3(GFZ%CW__],B>?H8-S__^E/_O__Z,;9__]F#Q]$
M```/MA=(B?B$TG0>9@\?1```2(/'`8#Z+P^V%T@/1,>$TG7N\\,/'T``\\-F
M#Q]$``!(A?\/A,\```!54TB#[`@/MB]`A.UT*4B)^^AAV?__2(U4`_](.=-R
M$.L[#Q]$``!(@^H!2#G3=#>`.B]T\NL=2(/$"$B-/7H5``!;7>G.V___9@\?
M1```@#HO=#A(@^H!2#G3<O)(.=-U*@\?1```0(#]+W3*2(/$"$B-/;`5``!;
M7>F8V___#Q^$``````"`.B]U"4B#Z@%(.=-R\D@IVDB-0@)(/0`0``!W.TB-
M/=QM(`!(@\(!N0`0``!(B=[H6]K__TB-!<1M(`!(@\0(6UW##Q]$``!(C3WF
M%```Z3S;__\/'T``,<#KX`\?0`!32(T].Q4``$B#[$!D2(L$)2@```!(B40D
M.#'`#[<%I18``$B-7"0,\P]O!7@6```/*40D$&:)1"0P,<#S#V\%=!8```\I
M1"0@Z$+U__](C3WW%```,<#H-/7__TB-/?$4```QP.@F]?__2(T][!0``#'`
MZ!CU__](C3WE%```,<#H"O7__TB-/><4```QP.C\]/__2(T]CA0``#'`Z.[T
M__](C3W7%```,<#HX/3__TB-/=,4```QP.C2]/__2(T]SQ0``#'`Z,3T__](
MC3U?%```,<#HMO3__TB-/;T4```QP$B)WNC5\___2(7`=!%(C3V3%```2(G&
M,<#H'_7__TB-/:<4```QP$B)WNBN\___2(7`=!%(C3VC%```2(G&,<#H^/3_
M_TB-/9T4```QP$B)WNB'\___2(7`=$)(C3WD$P``2(G&,<#HT?3__TB--4H5
M``!(C3T'%```,<#HO/3__TB+1"0X9$@S!"4H````=6)(@\1`6\-F#Q]$``!(
MC3U5%```,<!(B=[H+_/__TB%P'4J2(UT)"%(C3U+%```N0H```#SIG6D2(UT
M)"M(C3W)$P``,<#H8O3__^N/2(T]N1,``$B)QC'`Z$_T___I>?___^C%UO__
M#Q]$``!(@^P89$B+!"4H````2(E$)`@QP(L%-FL@`(/X_W092(M\)`AD2#,\
M)2@```!U0$B#Q!C##Q]``$B-="0$2(T]7!,``#'`Z)7R__](B<(QP$B%TG02
M#[82@/HP#Y7!,<"$T@^5P"'(B07C:B``Z[#H3-;__V:09BX/'X0``````$B#
M[`CH1];__XG'Z/#5__](A<!T"TB+`$B#Q`C##Q\`,<#K]&:09BX/'X0`````
M`$%454B)_5-(C3U:$P``2(/L$&1(BP0E*````$B)1"0(,<!(C70D!.@$\O__
M2(7`2(GN='R`.`!(B<-T=$B)Q^ALV/__2(7`=75(B>_HK]7__TB)WTF)Q.BD
MU?__28U\!`+HVM;__TB#[`A,C0T^$@``2(T-+1,``%-(Q\+_____2(G'28G$
M28GHO@$````QP.@KV/__2(T]S!(``$R)YC'`Z.KR__]86NL49@\?1```2(T]
ML1(``#'`Z-+R__](BT0D"&1(,P0E*````'4)2(/$$%M=05S#Z#35__\/'T``
M05=!5D%5051)B?U54TB-/:41``!(@>R(@0``9$B+!"4H````2(F$)'B!```Q
MP$B-!6\2``!,C60D+$C'1"1``````$C'A"28`````````$C'1"1@`````$B)
M1"0P2(T%`1$``$R)YDB)1"0X2(T%WA$``$B)1"1P2(T%RQ$``$B)1"1X2(T%
M'A(``$B)A"2`````2(T%S1$``$B)A"2(````2(T%"!(``$B)A"20````2(T%
MX!$``$B)1"102(T%\1$``$B)1"18,<#H@/#__TB%P'0)@#@`#X52`@``,<#H
M"_[__TB%P$B)PP^$CP(``$B)W^@GU/__2(U\``'H7=7__X`[`$F)QG0W3(T]
MK!$``$R)]0\?`$0/M@-(B>\QP$R)^4C'PO____^^`0```$B#PP%(@\4"Z*/6
M__^`.P!UUDB-7"1P2(T]`Q$``.L02(/#"$B+.TB%_P^$>`$``#'`3(GFZ.;O
M__](A<!(B<5TWH`X`'392(G'Z`'U__^%P'3-2(GOZ#76__](A<!)B<</A$$!
M``!F#Q^$``````!,B?J+"DB#P@2-@?_^_O[WT2'()8"`@(!TZ8G!P>D0J8"`
M```/1,%(C4H"2`]$T8G!`,%,B?%(@]H#3"GZBS%(@\$$C8;__O[^]]8A\"6`
M@("`=.F)QL'N$*F`@```#T3&2(UQ`D@/1,Z)QD``QDB#V0-,*?&-G`H$!```
M2&/;2(G?Z#G4__](B<5(C06;$```059,C0V7#P``2(T-@A```$V)^%!(Q\+_
M____O@$```!(B>\QP.B%U?__OL`!``!(B>_H&-+__X/X_T%805EU$NC:T?__
M1(L(08/Y$0^%TP@``(L]1V<@`.C"T___2(V0``(``$B)[K\!````Z-[4__^%
MP$&)QP^$0P$``$F+30!(BSU89R``2(T5\1```$F)Z+X!````,<`QV^C@U/__
MZWYF#Q]$```Q[68/'T0``$ACQ4B+7,0P2(7;=#N`.P!T-DB)WX/%`>B#\___
MA<!TWTB)W^BWU/__2(7`28G'#X6+_O__2&/%2(M<Q#!(A=MURV8/'T0``$4Q
M_^EP_O__2(G'2(D$).CD^___2(L$)$B)Q^AXU/__2(G##Q]$``!(BXPD>($`
M`&1(,PPE*````$B)V`^%Y0@``$B!Q(B!``!;74%<05U!7D%?PP\?0`!(C3T1
M#P``,>U(A?]T)F:0,<!,B>:#Q0'HL^W__TB%P'0%@#@`=2E(8\5(BWS$4$B%
M_W7<OPT```!(C1W=#@``Z)O2__])B<;I/OW__P\?`$B)Q^CHT___2(7`2(G#
M#X4-_?__Z\%F+@\?A```````BSW:92``Z%72__^+@!@"```E`/```#T`0```
M#X6<_O__BSVY92``Z#32__]$B[`<`@``Z!C1__]!.<8/A7S^__^+/9EE(`#H
M%-+__XN`&`(``"7_`0``/<`!```/A5O^__](B=_H!M+__TB-/3(.``!(B<-,
MB>8QP.CB[/__2(7`#X1I`0``2(G'Z$'3__])BWT`2(G&Z,7T__](A<!)B<0/
MA$D!``!,B>?H@=#__X/X`WX\2&/02(T](PX``+D%````28UT%/SSIG4D@_@$
M#X0+!@``@^@$2)A!@'P$_R\/A/H%``!F+@\?A```````,<#HB?G__X7`=14Q
M]DR)Y^@+TO__A<!!B<8/A?````!(C34I#@``2(T]`@T``$R-)?H-```QP$R-
M+;,,``#HC>W__^B(S___051,C0V@#```4$B-#;$-``!(Q\+_____28GHO@$`
M``!(B=\QP.B.TO__6%KK368N#Q^$``````#HZ\[__X,X$75+Z$'/__]!@\<!
M2(/L"$B-#7H-``!!5$%738GI4$F)Z$C'PO____^^`0```$B)WS'`Z$'2__](
M@\0@OL`!``!(B=_HT,[__X/X_W2K2(GOZ(/.__](C3WU"P``2(G>,<#HXNS_
M_TB)W^A*^?__Z77]__\/'T0``$V+90#IKO[__P\?@`````"Z`@```$C'QN[_
M__^)Q^B=T?__2(V$)'`!``"Z!@```$2)]TB)QDB)!"3HT<___X"\)'`!````
M=0Z`O"1Q`0``0P^$B04``#'2,?9$B??H7='__[B)J\WO3(VL)*````!(QX0D
MH`````$C16=(B80DJ````$@MB\X25TC'A"2X````=E0R$$B)A"2P````2`7R
M!!@K2,>$),@`````````2(F$),````!)C44X2,>$)-``````````QX0D&`$`
M``````!(B40D"`\?A```````2(LT)+H`@```1(GWZ!_/__^%P$F)Q$&)P`^.
M<0$``$B+O"3(````26/$2(N4)-````"--,=(.?Y(B;0DR````$B#T@!(P>@=
M2`'02(F$)-````!(8X0D&`$``(7`#X0=`0``2(M,)`A!N$````!(BS0D02G`
M13G$10].Q$B-/`%)8]!)B==(B50D$.C@SO__BX0D&`$``$0!^(/X0(F$)!@!
M```/A5;___]%B>!,B>]%*?A,BWPD$$P#/"1$B40D'.BZT___1(M$)!P/'T0`
M`$&#^#]^>4&-0,")1"0<P>@&08G$B40D$$F#Q`%)P>0&30'\#Q]$``#S00]O
M!TR)[TF#QT`/$80DV````/-!#V]'T`\1A"3H````\T$/;T?@#Q&$)/@```#S
M00]O1_`/$80D"`$``.A%T___33G\=;B+1"001(M$)!S!X`9!*<!(BWPD"$EC
MT+E(````3(G^1(E$)!#H]\W__T2+1"001(F$)!@!``#IA?[__P\?1```3(L\
M).E'____#Q^``````$2)]^A(S?__3(ND),@```!,B[0DT````$R)X$C!Z`.#
MX#^-4`%(F,:$!-@```"`@_HX#X^#`@``N#@````Q]BG02&/2@_@(28U4%3@/
M@]P"``"H!`^%A@,``(7`=`NH`L8"``^%B@,``$R)\$R)[T2(M"03`0``2,'H
M&$2(I"07`0``3(VL)$`!``"(A"00`0``3(GP2,'H$(B$)!$!``!,B?!,C37$
M"0``2,'H"(B$)!(!``!,B>!(P>@8B(0D%`$``$R)X$C!Z!"(A"05`0``3(G@
M13'D2,'H"(B$)!8!``#H"=+__TB+A"2@````2(G"B(0D(P$``$C!ZAA$#[;"
MB)0D(`$``$B)PDC!ZA"(E"0A`0``2(G"2(N$)*@```!(P>H(B)0D(@$``$B)
MPHB$)"<!``!(P>H8B)0D)`$``$B)PDC!ZA"(E"0E`0``2(G"2(N$)+````!(
MP>H(B)0D)@$``$B)PHB$)"L!``!(P>H8B)0D*`$``$B)PDC!ZA"(E"0I`0``
M2(G"2(N$)+@```!(P>H(B)0D*@$``$B)PHB$)"\!``!(P>H8B)0D+`$``$B)
MPDC!ZA"(E"0M`0``2(G"2(N$),````!(P>H(B)0D+@$``$B)PHB$)#,!``!(
MP>H8B)0D,`$``$B)PDC!ZA"(E"0Q`0``2(G"2,'J"(B4)#(!``#I#`````\?
M`$8/MH0D(`$``$N-?&4`,<!,B?%(Q\+_____O@$```!)@\0!Z%C-__])@_P4
M==)(C05Z"```QH0D:`$```!0055(C0TT"```3(T-(P<``+X!````28GH2,?"
M_____TB)WS'`Z!G-__]97NGG^O__9I!-BVT(387M#X0#^O__3(GOZ#O*__](
M@_@##X;Q^?__28UT!?Q(C3W;!P``N04```#SIDT/1.7IU?G__[A`````2&/*
M*=!)C4P-.'0/,=*)UH/"`3G"Q@0Q`'+S3(GOZ`W0__]F#^_`#Q&$)-@```!)
MQT5H`````$$/$45(00\115CI8_W__TF+30!(BSVO7B``2(T5"`@``$F)Z+X!
M````,<`QV^@WS/__Z=+W__^)P4C'`@````!(QT0*^`````!(C4H(2(/A^$@I
MR@'0@^#X@_@(#X(0_?__@^#X,=*)UX/""#G"2(DT.7+SZ?G\__^`O"1R`0``
M00^%:?K__X"\)',!``!##X5;^O__@+PD=`$``$@/A4WZ__^`O"1U`0``10^%
M/_K__[H"````2,?&QO___T2)]^B4R___3(L\)+HI````1(GW3(G^Z-#)__](
MC07H!@``4$%7Z7'^__^0QP(`````QT0"_`````#I=OS__S'_9HE\`O[I:OS_
M_^C<R/__9I!F+@\?A```````05=!5D%505154TB#[!B+/5Q=(`!D2(L$)2@`
M``!(B40D"#'`3(UL)`3HPLG__XL]/%T@`$B)P^BTR?__#[:3N````$B-/4H%
M``!,B>Z(D+D````QP.B6Y/__2(7`=`F`.#$/A`@#```QP.C![___BSW[7"``
MZ';)__](C34H!@``N0L```"Z`0```$B)Q^@=R?__2(7`#X3$````@ST];2``
M`4B+0!!$BS7"7"``3(M@*`^.KP```#'MNP$```#K.@\?@`````!)BW<02(L%
M!6T@`$ACTTB+/-#HP<C__X7`BQ7Y;"``#X4(`@``@\,!@\4!.=,/C?H!``!$
MB??H[<C__S')2&/53(GF2(G'Z+W)__](A<`/A,P!``!,BSA$BS5*7"``08M'
M#"4`!"``/0`$``!TDD2)]^BRR/__3(G^N0(````QTDB)Q^C0Q___1(LU&5P@
M`$B)QNEM____D$2+-0E<(`!$B??H@<C__TB--3@%``"Y`P```+H!````2(G'
MZ"C(__](A<!(B<-T-4B+0!"+/=9;(`!(BRCH3LC__TB-%0<%``!(B<=(B>[H
M7,?__TB+0Q!(BQCV0PY`#X7K`0``BSVE6R``Z"#(__](C37>!```N0,```"Z
M`0```$B)Q^C'Q___2(7`2(G#=#U(C3UJ`P``,<!,B>[H[N+__TB%P$B)Q0^$
M<@$``$B+0Q"+/5A;(`!(BQCHT,?__TB)ZDB)QTB)WNCBQO__BST\6R``Z+?'
M__](C35W!```N@$```!(B<?HP\?__XL]'5L@`$B)P^B5Q___2(T5:@0``$B)
MWDB)Q^BCQO__BSW]6B``Z'C'__](C3W:`@``QH"Y`````$R)[C'`Z&#B__](
MA<!(B<-(B05+:R``#X2=````OL`!``!(B=_H<,7__XU0`8/Z`78)@_@1#X4/
M`0``2(M$)`AD2#,$)2@````/A?8```!(@\086UU!7$%=05Y!7\,/'T``BQ7R
M:B``1(LU>UH@`(U"_SGH#X5G_O__@_H!#XY>_O__NP$```!FD$2)]X/#`>C5
MQO__3(GF2(G'Z!K%__\Y';1J(`!$BS4]6B``?]OI+?[__V8/'T0``$B+/9%J
M(`#H5/#__TB%P$B)PTB)!8]J(``/A43___](C3U"!```,<#HL\;__P\?`(!X
M`0`/A/7\___IZ?S__Y!(BP51:B``BSWC62``2(LH2(M#$$B+&.A4QO__2(GN
M2(G?Z`GG___I@O[__P\?0`"+/;I9(`#H-<;__TB)WDB)Q^B*QO__Z?K]___H
M`,7__XG!2(L%_VD@`$B-/?`#``!(B=I(BS`QP.@SQO__#Q\`55-(B?U(@^P(
MZ$+K__\/MA!(B<.$TG0:#Q^$``````!(@\`!@/HO#[802`]$V(32=>XQP.CG
M[?__2(7M=!V%P'09@'T``'032(T]+0(``+D$````2(G>\Z9T!TB#Q`A;7<-(
M@\0(2(GO6UWI0.3__TB-!?%8(``QR4B%P'0#2(L(Z>K$__]F+@\?A```````
M05=!5DF)UT%5051,C24>5"``54B-+1Y4(`!308G]28GV3"GE2(/L"$C!_0/H
M_\+__TB%[70@,=L/'X0``````$R)^DR)]D2)[T'_%-Q(@\,!2#G==>I(@\0(
M6UU!7$%=05Y!7\.09BX/'X0``````//#``!(@^P(2(/$",,````!``(`+BX`
M)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!
M3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!
M3%]#3$5!3@!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?4$%42`!54T52`%-94U1%
M30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E<R5S)7,`<&%R
M+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S
M=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)
M3TX`,2XP-#$`+64`+2T`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("```````````'!E<FQX<VDN8P`````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I
M9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S
M970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS
M965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R
M96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD
M:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED
M>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J
M(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`[
M"B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N
M86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D
M:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X
M*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F
M:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA
M;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L
M;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````
M``$;`SOL````'````("#__\X`0``0(?__V`!``!0A___1`8``(")__\(`0``
MD(K__W@!``"@H/__R`$``'"A__\4`@```*+__T`"``!0I/__C`(``-"E___8
M`@``8*;___@"``!`I___/`,``'"G__]4`P``P*?__VP#``"0J/__F`,``*"H
M__^L`P``P*K__PP$``#PJO__(`0``."K__]P!```P*W__Y0$``!`KO__L`0`
M`'"N___,!```4*___PP%``"PN___Q`4``*"___\0!@``$,#__W`&```PP/__
MB`8``*#`___0!@```````!0``````````7I2``%X$`$;#`<(D`$'$!0````<
M````<(C__RL``````````````!0``````````7I2``%X$`$;#`<(D`$``"0`
M```<````0(+__\`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1```
M`-B%__\(``````````````!,````7````!")__\.%@```$(.$(\"0@X8C@-&
M#B"-!$(.*(P%1`XPA@9!#CB#!T<.T`4#YA4*#CA!#C!!#BA"#B!"#AA"#A!"
M#@A!"P```$@```"L````T)[__\P`````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`H````^```
M`%2?__^$`````$$.$(8"00X8@P-'#C`"<PH.&$$.$$$."$$+`$@````D`0``
MN)___TP"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'2@Y@`R8!
M"@XX00XP00XH0@X@0@X80@X00@X(1`M(````<`$``+RA__]Q`0```$(.$(\"
M0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.\`%^"@XX00XP00XH0@X@0@X8
M0@X00@X(1PL`'````+P!``#PHO__@0````!!#A"#`FD*#@A&"P)0#@A`````
MW`$``&"C___>`````$(.$(X"0@X8C0-%#B",!$$.*(8%1`XP@P93#L`@`H0*
M#C!!#BA!#B!"#AA"#A!"#@A#"Q0````@`@``_*/__S``````1`X09PX(`!0`
M```X`@``%*3__TD`````1`X0?0X(`"@```!0`@``3*3__\$`````00X0A@)!
M#AB#`T<.P$`"IPH.&$$.$$$."$8+$````'P"``#PI/__!0````````!<````
MD`(``.RD__\:`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!U$.
MX"`"9`H..$$.,$$.*$(.($(.&$(.$$(."$0+`I8.Z"!+#O`@>0[H($$.X"``
M```0````\`(``*RF__\J`````````$P````$`P``R*;__^P`````2@X0A@)!
M#AB#`T0.('4*#AA(PPX00<8."$L+8@H.&$C##A!!Q@X(30L"0`X800X000X(
M1L/&4`X@@P.&`@``(````%0#``!HI___VP$```!!#A"#`DL.4`-L`0H.$$$.
M"$<+&````'@#```DJ?__=`````!$#B!O"@X(10L``!@```"4`P``B*G__R0`
M````1`X06`H."$0+```\````L`,``)RI___<`````$(.$(P"00X8A@-$#B"#
M!$L.,`)8#CA/#D!N#CA!#C!J"@X@00X800X00@X(00L`M````/`#```\JO__
M5`P```!"#A"/`D(.&(X#0@X@C01"#BB,!40.,(8&00XX@P=.#L"#`@,8`@[(
M@P)2#M"#`F@.R(,"0@[`@P(#`@$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"P.J
M`0[(@P)(#M"#`F$.R(,"00[`@P)C#LB#`DD.T(,"0@[8@P)$#N"#`ET.P(,"
M`_L$#LB#`D(.T(,":`[(@P)!#L"#`@-?`0H.R(,"0@[0@P)&"T@```"H!```
MY+7__^T#````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y0`\L"
M"@XX00XP00XH0@X@0@X80@X00@X(10LP````]`0``(BY__]P`````$$.$(8"
M00X8@P-'#B`"5@H.&$$.$$$."$$+1`X81`X000X(*````"@%```$@?__+0(`
M``!!#A"&`D$.&(,#1`Y0`[T!"@X800X000X(00L4````5`4``)BY__\6````
M``````````!$````;`4``*"Y__]E`````$(.$(\"0@X8C@-%#B"-!$(.*(P%
M2`XPA@9(#CB#!TT.0'(..$$.,$$.*$(.($(.&$(.$$(."``0````M`4``,BY
M__\"````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````@"$`
M``````!`(0````````````````````````````````````````$`````````
M`0`````````!`````````,L!`````````0````````#6`0````````$`````
M````X`$````````!`````````"\"`````````0````````![`P````````P`
M````````8!H````````-`````````*17````````&0````````!@JR``````
M`!L`````````"``````````:`````````&BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````[`0````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````V!0````````'`````````$`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````P!(```````#___]O``````(`
M````````\/__;P````#T$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(BK(```````````````````
M`````````)8:````````IAH```````"V&@```````,8:````````UAH`````
M``#F&@```````/8:````````!AL````````6&P```````"8;````````-AL`
M``````!&&P```````%8;````````9AL```````!V&P```````(8;````````
MEAL```````"F&P```````+8;````````QAL```````#6&P```````.8;````
M````]AL````````&'````````!8<````````)AP````````V'````````$8<
M````````5AP```````!F'````````'8<````````AAP```````"6'```````
M`*8<````````MAP```````#&'````````-8<````````YAP```````#V'```
M``````8=````````%AT````````F'0```````#8=````````1AT```````!6
M'0```````&8=````````=AT```````"&'0```````)8=````````IAT`````
M``"V'0```````,8=````````UAT```````#F'0```````/8=````````!AX`
M```````6'@```````"8>````````-AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````#(6@```````$=#
M0SH@*$1E8FEA;B`W+C(N,"TQ."D@-RXR+C```"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````#@"
M````````.`(````````<`````````````````````0``````````````````
M`!,````'`````@````````!4`@```````%0"````````(```````````````
M``````0````````````````````A````!P````(`````````=`(```````!T
M`@```````"0````````````````````$````````````````````-````/;_
M_V\"`````````)@"````````F`(```````#X``````````4`````````"```
M`````````````````#X````+`````@````````"0`P```````)`#````````
M>`D````````&`````0````@`````````&`````````!&`````P````(`````
M````"`T````````(#0```````.P$```````````````````!````````````
M````````3@```/___V\"`````````/01````````]!$```````#*````````
M``4``````````@`````````"`````````%L```#^__]O`@````````#`$@``
M`````,`2````````@``````````&`````@````@```````````````````!J
M````!`````(`````````0!,```````!`$P```````)@!````````!0``````
M```(`````````!@`````````=`````0```!"`````````-@4````````V!0`
M``````"(!0````````4````7````"``````````8`````````'X````!````
M!@````````!@&@```````&`:````````%P````````````````````0`````
M``````````````!Y`````0````8`````````@!H```````"`&@```````,`#
M```````````````````0`````````!``````````A`````$````&````````
M`$`>````````0!X````````(````````````````````"``````````(````
M`````(T````!````!@````````!0'@```````%`>````````4CD`````````
M`````````!````````````````````"3`````0````8`````````I%<`````
M``"D5P````````D````````````````````$````````````````````F0``
M``$````"`````````+!7````````L%<```````!0/P``````````````````
M"````````````````````*$````!`````@``````````EP````````"7````
M````[`````````````````````0```````````````````"O`````0````(`
M````````\)<```````#PEP```````/@%```````````````````(````````
M````````````N0````X````#`````````&"K(```````8*L````````(````
M````````````````"``````````(`````````,4````/`````P````````!H
MJR```````&BK````````"`````````````````````@`````````"```````
M``#1`````0````,`````````<*L@``````!PJP```````!,`````````````
M```````0````````````````````W@````8````#`````````(BK(```````
MB*L```````!``@````````8`````````"``````````0`````````(@````!
M`````P````````#(K2```````,BM````````,`(```````````````````@`
M````````"`````````#G`````0````,``````````+`@````````L```````
M`"`````````````````````(````````````````````[0````@````#````
M`````""P(```````(+````````"($```````````````````(```````````
M`````````/(````!````,````````````````````""P````````'0``````
M``````````````$``````````0`````````!`````P``````````````````
M```````]L````````/L````````````````````!````````````````````
